summaryrefslogtreecommitdiffstatshomepage
path: root/src/mess/drivers/comp4.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/mess/drivers/comp4.c')
-rw-r--r--src/mess/drivers/comp4.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/mess/drivers/comp4.c b/src/mess/drivers/comp4.c
index 472b36ea11e..cf882a4a343 100644
--- a/src/mess/drivers/comp4.c
+++ b/src/mess/drivers/comp4.c
@@ -13,6 +13,9 @@
Refer to the official manual for more information.
+ TODO:
+ - MCU clock is unknown
+
***************************************************************************/
#include "emu.h"
@@ -20,8 +23,7 @@
#include "comp4.lh"
-
-// master clock is cpu internal, the value below is an approximation
+// master clock is unknown, the value below is an approximation
#define MASTER_CLOCK (250000)